@@ -1,12 +1,20 @@
 /*
- * This file or a portion of this file is licensed under the
- * terms of the Globus Toolkit Public License, found at
- * http://www.globus.org/toolkit/download/license.html.
- * If you redistribute this file, with or without
- * modifications, you must include this notice in the file.
+ * Copyright 1999-2014 University of Chicago
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
-#include "globus_config.h"
-#ifdef TARGET_ARCH_WIN32
+
+#ifdef _WIN32
 #include "globus_i_xio_win32.h"
 
 typedef struct globus_l_xio_win32_socket_s
@@ -136,6 +144,11 @@ globus_l_xio_win32_socket_handle_read(
         globus_xio_operation_refresh_timeout(read_info->op);
     }
     
+    GlobusXIOSystemDebugPrintf(
+        GLOBUS_I_XIO_SYSTEM_DEBUG_INFO,
+        ("[%s] In globus_l_xio_win32_socket_handle_read fd=%lu, read_info->type=%d\n",
+             _xio_name,
+             (unsigned long)handle->socket, (int) read_info->type));
     switch(read_info->type)
     {
       case GLOBUS_I_XIO_SYSTEM_OP_ACCEPT:
@@ -150,7 +163,27 @@ globus_l_xio_win32_socket_handle_read(
                 
                 if(error != WSAECONNRESET && error != WSAEWOULDBLOCK)
                 {
-                    result = GlobusXIOErrorSystemError("accept", error);
+                    char errbuf[64];
+                    sprintf(errbuf, "accept, fd=%ld, error=%d",
+                        (long) handle->socket, error);
+                    result = GlobusXIOErrorSystemError(errbuf, error);
+                    GlobusXIOSystemDebugPrintf(
+                        GLOBUS_I_XIO_SYSTEM_DEBUG_INFO,
+                        ("[%s] Tried to accept new connection on fd=%lu, %s\n",
+                             _xio_name,
+                             (unsigned long)handle->socket, errbuf));
+
+                }
+                else
+                {
+                    char errbuf[64];
+                    sprintf(errbuf, "accept, fd=%ld, error=%d",
+                        (long) handle->socket, error);
+                    GlobusXIOSystemDebugPrintf(
+                        GLOBUS_I_XIO_SYSTEM_DEBUG_INFO,
+                        ("[%s] Tried to accept new connection on fd=%lu, %s\n",
+                             _xio_name,
+                             (unsigned long)handle->socket, errbuf));
                 }
             }
             else
@@ -165,8 +198,9 @@ globus_l_xio_win32_socket_handle_read(
                 read_info->nbytes++;
                 GlobusXIOSystemDebugPrintf(
                     GLOBUS_I_XIO_SYSTEM_DEBUG_INFO,
-                    ("[%s] Accepted new connection, fd=%lu\n",
-                         _xio_name, (unsigned long)new_fd));
+                    ("[%s] Accepted new connection on fd=%lu, fd=%lu\n",
+                         _xio_name,
+                         (unsigned long)handle->socket, (unsigned long)new_fd));
             }
         }
         break;
@@ -552,7 +586,7 @@ globus_l_xio_win32_socket_register_read(
         }
         
         read_info->state = GLOBUS_I_XIO_SYSTEM_OP_PENDING;
-        /* if select() functionality requested, only handle after we recieve
+        /* if select() functionality requested, only handle after we receive
          * read event
          */
         if(read_info->waitforbytes > 0 || handle->ready_events & FD_READ)
@@ -654,7 +688,7 @@ globus_l_xio_win32_socket_register_write(
         }
         
         write_info->state = GLOBUS_I_XIO_SYSTEM_OP_PENDING;
-        /* if select() functionality requested, only handle after we recieve
+        /* if select() functionality requested, only handle after we receive
          * write event
          * 
          * also dont call for connect operations.  waitforbytes == 0 in this
@@ -819,8 +853,8 @@ globus_xio_system_socket_destroy(
     
     GlobusXIOSystemDebugPrintf(
         GLOBUS_I_XIO_SYSTEM_DEBUG_INFO,
-        ("[%s] Unregistering event handle=%lu\n",
-            _xio_name, (unsigned long) handle->event));
+        ("[%s] Unregistering event handle=%lu for socket %ld\n",
+            _xio_name, (unsigned long) handle->event, (long) handle->socket));
             
     globus_i_xio_win32_event_unregister(handle->event_entry);
     globus_i_xio_win32_event_unlock(handle->event_entry);
